==> nextcloud-25.0.6.tgz: nextcloud/apps/password_policy/l10n/ko.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "비밀번호가 만료되었습니다, 비밀번호를 잊었어요를 사용해서 비밀번호 재설정",
    "Password must not have been used recently before." : "비밀번호는 최근에 쓰이지 않은 것이어야 합니다.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "암호가 가장 흔한 1,000,000개의 암호에 해당됩니다. 다른 암호를 선택하십시오.",
    "Password is present in compromised password list. Please choose a different password." : "암호가 유출된 암호 목록에 있습니다. 다른 암호를 사용하십시오.",
    "Password needs to contain at least one numeric character." : "암호에 적어도 하나의 숫자를 포함해야 합니다.",
    "Password needs to contain at least one special character." : "암호에 적어도 하나의 특수 문자를 포함해야 합니다.",
    "Password needs to contain at least one lower and one upper case character." : "암호에 적어도 하나의 소문자와 대문자를 포함해야 합니다.",
    "Password policy" : "암호 정책",
    "Allows admins to configure a password policy" : "관리자가 암호 정책을 변경할 수 있도록 허용",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "관리자가 최소 암호 길이 등 암호 정책을 설정할 수 있도록 허용",
    "User password history" : "사용자 비밀번호 기록",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "최대 로그인 실패 횟수 (0을 입력할 시 무제한이며 초과시 계정이 차단됩니다)",
    "Forbid common passwords" : "일반적인 암호 금지",
    "Enforce upper and lower case characters" : "대문자와 소문자 사용",
    "Enforce numeric characters" : "숫자 사용",
    "Enforce special characters" : "특수 문자 사용",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "haveibeenpwned.com에 등록된 유출된 암호 목록과 암호 비교",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "이 검사를 활성화하면 암호 해시를 만들고 해시의 첫 5글자를 haveibeenpwned.com API에 전송하여 유출된 암호 목록 중에 해당 글자로 시작하는 해시를 가져옵니다. 그 다음 Nextcloud 인스턴스에서 사용하고 있는 암호 중 해당 해시와 일치하는 암호를 검사합니다.",
    "Unknown error" : "알 수 없는 오류",
    "Settings saved" : "설정 저장됨",
    "Saved" : "저장됨"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/password_policy/l10n/ko.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "암호가 만료되었습니다, 암호를 잊었을 때처럼 암호를 재설정 하세요.",
    "Password must not have been used recently before." : "암호는 최근에 쓰이지 않은 것이어야 합니다.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "암호가 가장 흔한 1,000,000개의 암호에 해당됩니다. 다른 암호를 선택하십시오.",
    "Password is present in compromised password list. Please choose a different password." : "암호가 유출된 암호 목록에 있습니다. 다른 암호를 사용하십시오.",
    "Password needs to contain at least one numeric character." : "암호에 적어도 하나의 숫자를 포함해야 합니다.",
    "Password needs to contain at least one special character." : "암호에 적어도 하나의 특수 문자를 포함해야 합니다.",
    "Password needs to contain at least one lower and one upper case character." : "암호에 적어도 하나의 소문자와 대문자를 포함해야 합니다.",
    "Password policy" : "암호 정책",
    "Allows admins to configure a password policy" : "관리자가 암호 정책을 변경할 수 있도록 허용",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "관리자가 최소 암호 길이 등 암호 정책을 설정할 수 있도록 허용",
    "User password history" : "사용자 암호 기록",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "최대 로그인 실패 횟수 (0을 입력할 시 무제한이며 초과시 계정이 차단됩니다.)",
    "Forbid common passwords" : "일반적인 암호 금지",
    "Enforce upper and lower case characters" : "대문자와 소문자 사용",
    "Enforce numeric characters" : "숫자 사용",
    "Enforce special characters" : "특수 문자 사용",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "haveibeenpwned.com에 등록된 유출된 암호 목록과 암호 비교",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "이 검사를 활성화하면 암호 해시를 만들고 해시의 첫 5글자를 haveibeenpwned.com API에 전송하여 유출된 암호 목록 중에 해당 글자로 시작하는 해시를 가져옵니다. 그 다음 Nextcloud 인스턴스에서 사용하고 있는 암호 중 해당 해시와 일치하는 암호를 검사합니다.",
    "Unknown error" : "알 수 없는 오류",
    "Settings saved" : "설정 저장됨",
    "Saved" : "저장됨"
},
"nplurals=1; plural=0;");
